@@ -16,7 +16,6 @@ fn generate_key_snippet(key_args: &[MethodArgument], identifier: &str) -> proc_m
         .collect();
     quote! {
         let mut ___key___ = elrond_wasm::storage::StorageKey::<Self::Api>::new(
-            self.raw_vm_api(),
             &#id_literal[..],
         );
         #(#key_appends)*
@@ -32,7 +31,9 @@ pub fn generate_getter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
             quote! {
                 #msig {
                     #key_snippet
-                    elrond_wasm::storage::storage_get(self.raw_vm_api(), &___key___)
+                    elrond_wasm::storage::storage_get(
+                        elrond_wasm::types::ManagedRef::new(&___key___),
+                    )
                 }
             }
         },
@@ -56,7 +57,9 @@ pub fn generate_setter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::storage::storage_set(self.raw_vm_api(), &___key___, & #pat);
+            elrond_wasm::storage::storage_set(
+                elrond_wasm::types::ManagedRef::new(&___key___),
+                &#pat);
         }
     }
 }
@@ -71,7 +74,6 @@ pub fn generate_mapper_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
                 #msig {
                     #key_snippet
                     <#ty as elrond_wasm::storage::mappers::StorageMapper<Self::Api>>::new(
-                        self.raw_vm_api(),
                         ___key___
                     )
                 }
@@ -86,7 +88,9 @@ pub fn generate_is_empty_impl(m: &Method, identifier: &str) -> proc_macro2::Toke
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::storage::storage_get_len(self.raw_vm_api(), &___key___) == 0
+            elrond_wasm::storage::storage_get_len(
+                elrond_wasm::types::ManagedRef::new(&___key___),
+            ) == 0
         }
     }
 }
@@ -101,7 +105,9 @@ pub fn generate_clear_impl(m: &Method, identifier: &str) -> proc_macro2::TokenSt
     quote! {
         #msig {
             #key_snippet
-            elrond_wasm::storage::storage_clear(self.raw_vm_api(), &___key___);
+            elrond_wasm::storage::storage_clear(
+                elrond_wasm::types::ManagedRef::new(&___key___),
+            );
         }
     }
 }
