@@ -1,6 +1,7 @@
 #![allow(stable_features)]
 // ensure we don't run out of macro stack
 #![recursion_limit = "1024"]
+#![feature(proc_macro_quote)]
 
 #[macro_use]
 extern crate syn;
@@ -9,6 +10,7 @@ extern crate syn;
 extern crate quote;
 
 mod contract_impl;
+mod format;
 mod generate;
 mod macro_contract;
 mod macro_module;
@@ -57,3 +59,8 @@ pub fn managed_vec_item_derive(input: proc_macro::TokenStream) -> proc_macro::To
 
     managed_vec_item_derive::managed_vec_item_derive(&ast)
 }
+
+#[proc_macro]
+pub fn format_receiver_args(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
+    format::format_receiver_args_macro(input)
+}
